@@ -1,8 +1,8 @@
 use crate::prelude::*;
 use crate::{cpu_arch_state, CPUArchPtr};
 
-use strum_macros::{EnumString, EnumIter, ToString};
 use strum::IntoEnumIterator;
+use strum_macros::{EnumIter, EnumString, ToString};
 
 // Arch-specific mappings ----------------------------------------------------------------------------------------------
 
@@ -105,7 +105,7 @@ pub enum Reg {
 static RET_REGS: &'static [Reg] = &[Reg::X0, Reg::X1, Reg::X2, Reg::X3];
 
 /// MIPS named guest registers
-#[cfg(any(feature = "mips", feature = "mipsel"))]
+#[cfg(any(feature = "mips", feature = "mipsel", feature = "mips64"))]
 #[derive(Debug, Copy, Clone, PartialEq, Eq, EnumString, EnumIter, ToString)]
 pub enum Reg {
     ZERO = 0,
@@ -143,7 +143,7 @@ pub enum Reg {
 }
 
 /// MIPS return registers
-#[cfg(any(feature = "mips", feature = "mipsel"))]
+#[cfg(any(feature = "mips", feature = "mipsel", feature = "mips64"))]
 static RET_REGS: &'static [Reg] = &[Reg::V0, Reg::V1];
 
 // TODO: support floating point set as well? Separate QEMU bank.
@@ -194,14 +194,19 @@ static RET_REGS: &'static [Reg] = &[Reg::R3, Reg::R4];
 
 /// Get stack pointer register
 pub fn reg_sp() -> Reg {
-
     #[cfg(feature = "i386")]
     return Reg::ESP;
 
     #[cfg(feature = "x86_64")]
     return Reg::RSP;
 
-    #[cfg(any(feature = "arm", feature = "aarch64", feature = "mips", feature = "mipsel"))]
+    #[cfg(any(
+        feature = "arm",
+        feature = "aarch64",
+        feature = "mips",
+        feature = "mipsel",
+        feature = "mips64"
+    ))]
     return Reg::SP;
 
     #[cfg(any(feature = "ppc"))]
@@ -216,7 +221,6 @@ pub fn reg_ret_val() -> &'static [Reg] {
 
 /// Get return address register
 pub fn reg_ret_addr() -> Option<Reg> {
-
     #[cfg(feature = "i386")]
     return None;
 
@@ -226,7 +230,7 @@ pub fn reg_ret_addr() -> Option<Reg> {
     #[cfg(any(feature = "arm", feature = "aarch64", feature = "ppc"))]
     return Some(Reg::LR);
 
-    #[cfg(any(feature = "mips", feature = "mipsel"))]
+    #[cfg(any(feature = "mips", feature = "mipsel", feature = "mips64"))]
     return Some(Reg::RA);
 }
 
@@ -245,7 +249,7 @@ pub fn get_reg<T: Into<Reg>>(cpu: &CPUState, reg: T) -> target_ulong {
         val = (*cpu_arch).xregs[reg.into() as usize];
     }
 
-    #[cfg(any(feature = "mips", feature = "mipsel"))]
+    #[cfg(any(feature = "mips", feature = "mipsel", feature = "mips64"))]
     unsafe {
         val = (*cpu_arch).active_tc.gpr[reg.into() as usize];
     }
@@ -272,7 +276,7 @@ pub fn set_reg<T: Into<Reg>>(cpu: &CPUState, reg: T, val: target_ulong) {
         (*cpu_arch).regs[reg.into() as usize] = val;
     }
 
-    #[cfg(any(feature = "mips", feature = "mipsel"))]
+    #[cfg(any(feature = "mips", feature = "mipsel", feature = "mips64"))]
     unsafe {
         (*cpu_arch).active_tc.gpr[reg.into() as usize] = val;
     }
@@ -317,7 +321,7 @@ pub fn get_pc(cpu: &CPUState) -> target_ulong {
         val = (*cpu_arch).nip;
     }
 
-    #[cfg(any(feature = "mips", feature = "mipsel"))]
+    #[cfg(any(feature = "mips", feature = "mipsel", feature = "mips64"))]
     unsafe {
         val = (*cpu_arch).active_tc.PC;
     }
@@ -348,7 +352,7 @@ pub fn set_pc(cpu: &mut CPUState, pc: target_ulong) {
         (*cpu_arch).nip = pc;
     }
 
-    #[cfg(any(feature = "mips", feature = "mipsel"))]
+    #[cfg(any(feature = "mips", feature = "mipsel", feature = "mips64"))]
     unsafe {
         (*cpu_arch).active_tc.PC = pc;
     }
