@@ -52,7 +52,7 @@
 //! |:---------:|:-----------------------:|:---------------:|
 //! | [`init`]  | [`before_block_exec`]   | [`osi`](plugins::osi) |
 //! | [`Panda`] | [`virt_mem_after_read`] | [`proc_start_linux`](plugins::proc_start_linux) |
-//! | [`hook`]  | [`virt_mem_after_write`]| [`hooks2`](plugins::hooks2) |
+//! | [`mod@hook`]  | [`virt_mem_after_write`]| [`hooks2`](plugins::hooks2) |
 //! | [`on_sys`]| [`asid_changed`]        | [`guest_plugin_manager`](plugins::guest_plugin_manager) |
 //! | [`uninit`]| [`before_block_exec_invalidate_opt`] ||
 //! | [`regs`]  | [`insn_translate`]      ||
@@ -67,6 +67,9 @@ pub use panda_sys as sys;
 #[doc(inline)]
 pub use panda_macros as cbs;
 
+#[doc(inline)]
+pub use plugins::hooks::hook;
+
 #[doc(hidden)]
 pub use {lazy_static, paste};
 
@@ -107,6 +110,14 @@ pub mod taint;
 
 pub use enums::arch::*;
 
+/// A set of types PANDA frequently requires but have a low likelihood of clashing with
+/// other types you import, for use as a wildcard import.
+///
+/// ## Example
+///
+/// ```
+/// use panda::prelude::*;
+/// ```
 pub mod prelude {
     pub use crate::panda_arg::PandaArgs;
     pub use crate::sys::target_long;
